@@ -31,6 +31,9 @@ class YtmusicProvider(AbstractProvider, ProviderV2):
         self._http_proxy = http_proxy
         self.service.setup_http_proxy(http_proxy)
 
+    def setup_http_timeout(self, timeout):
+        self.service.setup_timeout(timeout)
+
     # noinspection PyPep8Naming
     class meta:
         identifier = 'ytmusic'
@@ -50,7 +53,11 @@ class YtmusicProvider(AbstractProvider, ProviderV2):
 
     @user.setter
     def user(self, user):
-        self.service.reload()
+        if user is not None:
+            headerfile = HEADER_FILE
+        else:
+            headerfile = None
+        self.service.reinitialize_by_headerfile(headerfile)
         self._user = user
 
     def use_model_v2(self, mtype):
